==> ListPaste-1.2.0-src.zip: ListPaste-1.2.0-src/ListPaste/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by ListPaste.rc
//
#define IDM_ABOUTBOX                    0x0010
#define IDM_OPTION_DIALOG               0x0020
#define IDD_ABOUTBOX                    100
#define IDS_ABOUTBOX                    101
#define IDD_LISTPASTE_DIALOG            102
#define IDS_OPTION_DIALOG               102
#define IDS_GROUP_NAME_DEFAULT          103
#define IDS_GROUP_NAME_CLIPBOARD        104
#define IDS_GROUP_NAME_NEW_GROUP        105
#define IDS_COLUMN_GROUP_NAME           106
#define IDS_COLUMN_ITEM_COUNT           107
#define IDS_ERROR_SAVE                  108
#define IDS_ERROR_LOAD                  109
#define IDS_ERROR_DELETE_CURRENT_GROUP  110
#define IDS_MENU_EXPLORER               111
#define IDR_MAINFRAME                   128
#define IDD_OPTION_DIALOG               129
#define IDD_DIALOG_DATA_GROUP           130
#define IDD_ABOUTBOX_NOLINK             131
#define IDC_EDIT_SEARCH                 1001
#define IDC_CHECK_MATCH_FIRST           1002
#define IDC_LIST_TEXTS                  1003
#define IDC_CHECK_TOPMOST               1004
#define IDC_CHECK_CONTROL_IME           1005
#define IDC_RADIO_DONT_WATCH_CLIPBOARD  1006
#define IDC_RADIO_WATCH_CLIPBOARD_TO_CURRENT_GROUP 1007
#define IDC_RADIO_WATCH_CLIPBOARD_TO_CLIPBOARD_GROUP 1008
#define IDC_EDIT_CLIPBOARD_RECORD_SIZE  1009
#define IDC_CHECK_SKIP_EMPTY_LINES      1010
#define IDC_CHECK_TRIM_SPACES           1011
#define IDC_BUTTON_DEFAULT              1012
#define IDC_SYSLINK_URL                 1013
#define IDC_COMBO_GROUP                 1014
#define IDC_BUTTON_GROUP                1015
#define IDC_LIST_DATA_GROUP             1016
#define IDC_STATIC_GROUP                1017
#define IDC_STATIC_SEARCH               1018
#define IDC_CHECK_TRANSPARENT_ON_INACTIVE 1019
#define IDC_CHECK_TRANSPARENT_ON_DRAG   1020
#define IDC_EDIT_TRANSPARENT_ALPHA      1021
#define IDC_EDIT_INSERT                 20001
#define IDC_EDIT_UP                     20002
#define IDC_EDIT_DOWN                   20003
#define IDC_EDIT_EDITTEXT               20004
#define IDC_EDIT_RENAME                 20005

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        132
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1022
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> ListPaste-1.5.0-src.zip: ListPaste-1.5.0-src/ListPaste/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by ListPaste.rc
//
#define IDM_ABOUTBOX                    0x0010
#define IDM_OPTION_DIALOG               0x0020
#define IDD_ABOUTBOX                    100
#define IDS_ABOUTBOX                    101
#define IDD_LISTPASTE_DIALOG            102
#define IDS_OPTION_DIALOG               102
#define IDS_GROUP_NAME_DEFAULT          103
#define IDS_GROUP_NAME_CLIPBOARD        104
#define IDS_GROUP_NAME_NEW_GROUP        105
#define IDS_COLUMN_GROUP_NAME           106
#define IDS_COLUMN_ITEM_COUNT           107
#define IDS_ERROR_SAVE                  108
#define IDS_ERROR_LOAD                  109
#define IDS_ERROR_DELETE_CURRENT_GROUP  110
#define IDS_MENU_EXPLORER               111
#define IDR_MAINFRAME                   128
#define IDD_OPTION_DIALOG               129
#define IDD_DIALOG_DATA_GROUP           130
#define IDD_ABOUTBOX_NOLINK             131
#define IDC_EDIT_SEARCH                 1001
#define IDC_CHECK_MATCH_FIRST           1002
#define IDC_LIST_TEXTS                  1003
#define IDC_CHECK_TOPMOST               1004
#define IDC_CHECK_CONTROL_IME           1005
#define IDC_RADIO_DONT_WATCH_CLIPBOARD  1006
#define IDC_RADIO_WATCH_CLIPBOARD_TO_CURRENT_GROUP 1007
#define IDC_RADIO_WATCH_CLIPBOARD_TO_CLIPBOARD_GROUP 1008
#define IDC_EDIT_CLIPBOARD_RECORD_SIZE  1009
#define IDC_CHECK_SKIP_EMPTY_LINES      1010
#define IDC_CHECK_TRIM_SPACES           1011
#define IDC_BUTTON_DEFAULT              1012
#define IDC_SYSLINK_URL                 1013
#define IDC_COMBO_GROUP                 1014
#define IDC_BUTTON_GROUP                1015
#define IDC_LIST_DATA_GROUP             1016
#define IDC_STATIC_GROUP                1017
#define IDC_STATIC_SEARCH               1018
#define IDC_CHECK_TRANSPARENT_ON_INACTIVE 1019
#define IDC_CHECK_TRANSPARENT_ON_DRAG   1020
#define IDC_EDIT_TRANSPARENT_ALPHA      1021
#define IDC_CHECK_SHRINK_ON_INACTIVE    1022
#define IDC_EDIT_INSERT                 20001
#define IDC_EDIT_UP                     20002
#define IDC_EDIT_DOWN                   20003
#define IDC_EDIT_EDITTEXT               20004
#define IDC_EDIT_RENAME                 20005
#define IDC_VIEW_UPDATE                 20006
#define IDC_OPTION_DIALOG               20007

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        132
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1023
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
